import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_test_form.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';


/// Form state for the form that allows you to test your knowledge of the verb
class VerbIndicativeTestFormState extends State<VerbIndicativeTestForm> {

  String _adaptedPronoun(String isoLang, String pronoun, String actual) {
    //TODO refactor with Strategy or the likes
    if ("fr" == isoLang) {
      if ("" != actual && "je" == pronoun &&
          (actual.substring(0, 1) == 'a' ||
              actual.substring(0, 1) == 'e' ||
              actual.substring(0, 1) == 'i' ||
              actual.substring(0, 1) == 'o' ||
              actual.substring(0, 1) == 'u')) {
        return "j\'";
      }
    }
    return pronoun;
  }



  @override
  Widget build(BuildContext context) {
    final VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    return SafeArea(
      child: Scaffold(
          body: Center(
            child: ListView.builder(
                key: Key('scroll_test_${testModel.verb.infinitive}'),
                itemCount: 6,
                scrollDirection: Axis.vertical,
                controller: ScrollController(),
                physics: ScrollPhysics(
                  parent: AlwaysScrollableScrollPhysics(),
                ),
                itemBuilder: (BuildContext context, int index) {
                  return Padding(
                    padding: const EdgeInsets.fromLTRB(20, 0, 20, 0),
                    child: Card(
                      child: ListTile(
                        visualDensity: VisualDensity.comfortable,
                        contentPadding: EdgeInsets.fromLTRB(15, 5, 30, 5),
                        dense: true,
                        leading: _pronounCell(context, index),
                        title: _verbCell(context, index),
                      ),
                      elevation: 5.0,
                    ),
                  );
                }),
          )
      ),
    );
  }

  SizedBox _pronounCell(BuildContext context, int person) {
    final VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    return SizedBox(
      height: 70,
      width: 85,
      child: Container(
        alignment: Alignment.center,
        child: Text(
          "${_adaptedPronoun(
              testModel.targetLanguageIso,
              testModel.pronouns[person],
              testModel.verb.indicative[person])}",
          style: TextStyle(
            color: Colors.blue,
            fontSize: 25,
          ),
          textAlign: TextAlign.center,
        ),
      ),
    );
  }

  Container _verbCell(BuildContext context, int person) {
    final VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    return Container(
      child: SizedBox(
        height: 40,
        width: 150,
        child: Container(
          alignment: Alignment.center,
          child: TextField(
            key: Key('test_${testModel.verb.infinitive}_${person}'),
            obscureText: false,
            autofocus: false,
            decoration: InputDecoration(
              border: OutlineInputBorder(),
            ),
            readOnly: false,
            onSubmitted: (String inputValue) {
              testModel.add(inputValue, person);
            },
            onChanged: (String inputValue) {
              testModel.add(inputValue, person);
            },
          ),
        ),
      ),
    );
  }

}