import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_test_form.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// The Route that allows you to test your knowledge of the verb that you want
/// to learn
class VerbIndicativeTestRoute extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        theme: CustomTheme.lightTheme,
        home: SafeArea(
          child: Scaffold(
            appBar: AppBar(
              actions: [
                _repeatIcon(context),
                _homeIcon(context),
              ],
              title: _titleCell(context),
            ),
            body: Container(child: VerbIndicativeTestForm()),
            floatingActionButton: _evaluateButton(context),
            ),
          ),
        );
  }

  IconButton _homeIcon(BuildContext context) {
    return IconButton(
        key: Key('home_button'),
        onPressed: () {
          Navigator.restorablePopAndPushNamed(context, '/verbSelectionRoute');
        },
        icon: Icon(Icons.home));
  }

  IconButton _repeatIcon(BuildContext context) {
    return IconButton(
        key: Key('back_button'),
        onPressed: () {
          Navigator.popAndPushNamed(context, '/verbIndicativeStudyRoute');
        },
        icon: Icon(Icons.refresh));
  }

  Text _titleCell(BuildContext context) {
    final VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    return Text("Vervoeging ${testModel.verb.infinitive}");
  }

  FloatingActionButton _evaluateButton(BuildContext context) {
    final VerbTestModel testModel = Provider.of<VerbTestModel>(context, listen: false);
    return FloatingActionButton(
      key: Key('evaluate_${testModel.verb.infinitive}'),
      child: Icon(Icons.arrow_forward),
      onPressed: () {
        if (testModel.isComplete()) {
          Navigator.restorablePopAndPushNamed(context, '/verbEvaluateRoute');
        }
      },
    );
  }
}